@@ -1,24 +1,25 @@
 //
-// Copyright (c) 2021 RepliXio Ltd. All rights reserved.
+// Copyright (c) 2022 RepliXio Ltd. All rights reserved.
 // Use is subject to license terms.
 //
 
-use kube::Resource;
-
 use super::*;
 
 pub trait RoleBindingExt: super::ResourceExt {
-    fn new(name: impl ToString, role: &rbacv1::Role) -> Self;
+    fn new<T: IsRole>(name: impl ToString, role: &T) -> Self;
     #[must_use]
     fn subjects(self, subjects: impl IntoIterator<Item = rbacv1::Subject>) -> Self;
 }
 
 impl RoleBindingExt for rbacv1::RoleBinding {
-    fn new(name: impl ToString, role: &rbacv1::Role) -> Self {
+    fn new<T: IsRole>(name: impl ToString, role: &T) -> Self
+    where
+        T: IsRole,
+    {
         let metadata = Self::metadata(name);
         let role_ref = rbacv1::RoleRef {
-            api_group: rbacv1::Role::group(&()).to_string(),
-            kind: rbacv1::Role::kind(&()).to_string(),
+            api_group: <T as kube::Resource>::group(&()).to_string(),
+            kind: <T as kube::Resource>::kind(&()).to_string(),
             name: role.name(),
         };
         Self {
@@ -34,3 +35,8 @@ impl RoleBindingExt for rbacv1::RoleBinding {
         Self { subjects, ..self }
     }
 }
+
+pub trait IsRole: kube::Resource<DynamicType = ()> {}
+
+impl IsRole for rbacv1::Role {}
+impl IsRole for rbacv1::ClusterRole {}
