@@ -1,5 +1,5 @@
 //
-// Copyright (c) 2021 RepliXio Ltd. All rights reserved.
+// Copyright (c) 2022 RepliXio Ltd. All rights reserved.
 // Use is subject to license terms.
 //
 
@@ -18,6 +18,8 @@ use super::*;
 #[cfg(feature = "capi")]
 mod capi;
 mod helper;
+#[cfg(feature = "runtime")]
+mod runtime;
 
 #[derive(Clone)]
 pub struct Kubectl {
@@ -75,37 +77,6 @@ impl Kubectl {
         Ok(text)
     }
 
-    #[cfg(feature = "runtime")]
-    pub async fn create_global_crd(
-        &self,
-        crd: apiextensionsv1::CustomResourceDefinition,
-    ) -> anyhow::Result<apiextensionsv1::CustomResourceDefinition> {
-        use anyhow::Context;
-        use kube::runtime::wait;
-        use wait::conditions::is_crd_established;
-
-        let crd = self.create_global_crd_impl(crd).await?;
-        let name = crd
-            .metadata
-            .name
-            .as_ref()
-            .context("crd does not have name")?;
-
-        wait::await_condition(self.crds(), name, is_crd_established())
-            .await
-            .context("failed to established crd")?;
-        Ok(crd)
-    }
-
-    #[cfg(feature = "runtime")]
-    pub async fn ensure_crd_is_installed(
-        &self,
-        crd: apiextensionsv1::CustomResourceDefinition,
-    ) -> anyhow::Result<()> {
-        self.create_global_crd(crd).await?;
-        Ok(())
-    }
-
     pub async fn ensure_global_k_is_installed<K>(&self, object: K) -> kube::Result<K>
     where
         K: kube::ResourceExt + ser::Serialize + de::DeserializeOwned + Clone + fmt::Debug,
