@@ -295,6 +295,7 @@ impl super::Kubectl {
         use kube::api::entry::CommitError;
         use kube::api::entry::Entry;
         use kube::error::ErrorResponse;
+        let pp = api::PostParams::default();
         let default = default.as_ref();
 
         let mut last_err = None;
@@ -315,7 +316,7 @@ impl super::Kubectl {
             };
             let mut entry = entry.and_modify(&mut update_fn);
 
-            let e = match entry.commit().await {
+            let e = match entry.commit(&pp).await {
                 Err(CommitError::Save(kube::Error::Api(e))) if e.code == CONFLICT.as_u16() => e,
                 // return for all other case
                 Ok(()) => return Ok(entry.into_object()),
@@ -491,39 +492,6 @@ impl super::Kubectl {
         self.crds().list(&lp).await.map(|object| object.items)
     }
 
-    #[cfg(feature = "runtime")]
-    pub(crate) async fn create_global_crd_impl(
-        &self,
-        crd: apiextensionsv1::CustomResourceDefinition,
-    ) -> kube::Result<apiextensionsv1::CustomResourceDefinition> {
-        use kube::Error::Api;
-        let name = crd.name();
-        let crds = self.crds();
-        let conflict = http::StatusCode::CONFLICT.as_u16();
-
-        let pp = self.post_params();
-        let result = crds.create(&pp, &crd).await;
-        match result {
-            Err(Api(e)) if e.code == conflict && e.reason == "AlreadyExists" => {
-                let existing = crds.get(&name).await?;
-                // https://kubernetes.io/docs/tasks/extend-kubernetes/custom-resources/custom-resource-definitions/
-                // One and only one version must be marked as the storage version.
-                let crd_v = crd.spec.versions.iter().find(|v| v.storage);
-                let existing_v = existing.spec.versions.iter().find(|v| v.storage);
-
-                // make sure that the schemas match - if not propagate conflict error
-                crd_v
-                    .and_then(|v| v.schema.as_ref())
-                    .zip(existing_v.and_then(|v| v.schema.as_ref()))
-                    .filter(|(crd_schema, existing_schema)| crd_schema == existing_schema)
-                    .ok_or(Api(e))?;
-
-                Ok(existing)
-            }
-            _ => result,
-        }
-    }
-
     pub(super) async fn ensure_global_k_is_installed_impl<K>(
         &self,
         mut object: K,
