@@ -93,3 +93,18 @@ pub fn owner_reference(
         uid: owner.uid?,
     })
 }
+
+pub fn from_kubeconfig_error(err: kube::config::KubeconfigError) -> kube::Error {
+    // This is a workaround until the real error code will be possible to create
+    // let infer = config::InferConfigError {
+    //     in_cluster: config::InClusterError::MissingEnvironmentVariables, // Dummy error
+    //     kubeconfig: err,
+    // };
+    // kube::Error::InferConfig(infer)
+    log::warn!(
+        "Replacing {} with Error::LinesCodecMaxLineLengthExceeded",
+        err
+    );
+
+    kube::Error::LinesCodecMaxLineLengthExceeded
+}
